@@ -113,7 +113,7 @@ class AirConditioningCompanionMcn02(Device):
     ) -> None:
         if start_id is None:
             start_id = random.randint(0, 999)  # nosec
-        super().__init__(ip, token, start_id, debug, lazy_discover)
+        super().__init__(ip, token, start_id, debug, lazy_discover, model=model)
 
         if model != MODEL_ACPARTNER_MCN02:
             _LOGGER.error(
