@@ -8,6 +8,7 @@ import click
 from .click_common import EnumType, command, format_output
 from .device import Device, DeviceInfo, DeviceStatus
 from .exceptions import DeviceError, DeviceException
+from .utils import deprecated
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -197,12 +198,16 @@ class AirHumidifierStatus(DeviceStatus):
     def water_level(self) -> Optional[int]:
         """Return current water level in percent.
 
-        If water tank is full, depth is 125.
+        If water tank is full, depth is 120. If water tank is overfilled, depth is 125.
         """
         depth = self.data.get("depth")
-        if depth is not None and depth <= 125:
-            return int(depth / 1.25)
-        return None
+        if depth is None or depth > 125:
+            return None
+
+        if depth < 0:
+            return 0
+
+        return int(min(depth / 1.2, 100))
 
     @property
     def water_tank_detached(self) -> Optional[bool]:
@@ -246,25 +251,6 @@ class AirHumidifierStatus(DeviceStatus):
 class AirHumidifier(Device):
     """Implementation of Xiaomi Mi Air Humidifier."""
 
-    def __init__(
-        self,
-        ip: str = None,
-        token: str = None,
-        start_id: int = 0,
-        debug: int = 0,
-        lazy_discover: bool = True,
-        model: str = MODEL_HUMIDIFIER_V1,
-    ) -> None:
-        super().__init__(ip, token, start_id, debug, lazy_discover)
-
-        if model in AVAILABLE_PROPERTIES:
-            self.model = model
-        else:
-            self.model = MODEL_HUMIDIFIER_V1
-
-        # TODO: convert to use generic device info in the future
-        self.device_info: Optional[DeviceInfo] = None
-
     @command(
         default_output=format_output(
             "",
@@ -289,10 +275,10 @@ class AirHumidifier(Device):
     )
     def status(self) -> AirHumidifierStatus:
         """Retrieve properties."""
-        if self.device_info is None:
-            self.device_info = self.info()
 
-        properties = AVAILABLE_PROPERTIES[self.model]
+        properties = AVAILABLE_PROPERTIES.get(
+            self.model, AVAILABLE_PROPERTIES[MODEL_HUMIDIFIER_V1]
+        )
 
         # A single request is limited to 16 properties. Therefore the
         # properties are divided into multiple requests
@@ -309,7 +295,7 @@ class AirHumidifier(Device):
         values = self.get_properties(properties, max_properties=_props_per_request)
 
         return AirHumidifierStatus(
-            defaultdict(lambda: None, zip(properties, values)), self.device_info
+            defaultdict(lambda: None, zip(properties, values)), self.info()
         )
 
     @command(default_output=format_output("Powering on"))
@@ -412,6 +398,7 @@ class AirHumidifier(Device):
             return self.send("set_dry", ["off"])
 
 
+@deprecated("Use AirHumidifer(model='zhimi.humidifier.ca1")
 class AirHumidifierCA1(AirHumidifier):
     def __init__(
         self,
@@ -426,6 +413,7 @@ class AirHumidifierCA1(AirHumidifier):
         )
 
 
+@deprecated("Use AirHumidifer(model='zhimi.humidifier.cb1")
 class AirHumidifierCB1(AirHumidifier):
     def __init__(
         self,
@@ -440,6 +428,7 @@ class AirHumidifierCB1(AirHumidifier):
         )
 
 
+@deprecated("Use AirHumidifier(model='zhimi.humidifier.cb2')")
 class AirHumidifierCB2(AirHumidifier):
     def __init__(
         self,
