@@ -129,11 +129,17 @@ class AirHumidifierMiotStatus(DeviceStatus):
     def water_level(self) -> Optional[int]:
         """Return current water level in percent.
 
-        If water tank is full, depth is 125.
+        If water tank is full, raw water_level value is 120. If water tank is
+        overfilled, raw water_level value is 125.
         """
-        if self.data["water_level"] <= 125:
-            return int(self.data["water_level"] / 1.25)
-        return None
+        water_level = self.data["water_level"]
+        if water_level > 125:
+            return None
+
+        if water_level < 0:
+            return 0
+
+        return int(min(water_level / 1.2, 100))
 
     @property
     def water_tank_detached(self) -> bool:
