@@ -8,6 +8,7 @@ import click
 from .click_common import EnumType, command, format_output
 from .device import Device, DeviceStatus
 from .exceptions import DeviceException
+from .utils import deprecated
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -100,22 +101,6 @@ class AirDogStatus(DeviceStatus):
 
 
 class AirDogX3(Device):
-    def __init__(
-        self,
-        ip: str = None,
-        token: str = None,
-        start_id: int = 0,
-        debug: int = 0,
-        lazy_discover: bool = True,
-        model: str = MODEL_AIRDOG_X3,
-    ) -> None:
-        super().__init__(ip, token, start_id, debug, lazy_discover)
-
-        if model in AVAILABLE_PROPERTIES:
-            self.model = model
-        else:
-            self.model = MODEL_AIRDOG_X3
-
     @command(
         default_output=format_output(
             "",
@@ -131,7 +116,9 @@ class AirDogX3(Device):
     def status(self) -> AirDogStatus:
         """Retrieve properties."""
 
-        properties = AVAILABLE_PROPERTIES[self.model]
+        properties = AVAILABLE_PROPERTIES.get(
+            self.model, AVAILABLE_PROPERTIES[MODEL_AIRDOG_X3]
+        )
         values = self.get_properties(properties, max_properties=10)
 
         return AirDogStatus(defaultdict(lambda: None, zip(properties, values)))
@@ -191,6 +178,7 @@ class AirDogX3(Device):
 
 
 class AirDogX5(AirDogX3):
+    @deprecated("Use AirDogX3(model='airdog.airpurifier.x5')")
     def __init__(
         self,
         ip: str = None,
@@ -200,15 +188,11 @@ class AirDogX5(AirDogX3):
         lazy_discover: bool = True,
         model: str = MODEL_AIRDOG_X5,
     ) -> None:
-        super().__init__(ip, token, start_id, debug, lazy_discover)
-
-        if model in AVAILABLE_PROPERTIES:
-            self.model = model
-        else:
-            self.model = MODEL_AIRDOG_X5
+        super().__init__(ip, token, start_id, debug, lazy_discover, model=model)
 
 
 class AirDogX7SM(AirDogX3):
+    @deprecated("Use AirDogX3(model='airdog.airpurifier.x7sm')")
     def __init__(
         self,
         ip: str = None,
@@ -218,9 +202,4 @@ class AirDogX7SM(AirDogX3):
         lazy_discover: bool = True,
         model: str = MODEL_AIRDOG_X7SM,
     ) -> None:
-        super().__init__(ip, token, start_id, debug, lazy_discover)
-
-        if model in AVAILABLE_PROPERTIES:
-            self.model = model
-        else:
-            self.model = MODEL_AIRDOG_X7SM
+        super().__init__(ip, token, start_id, debug, lazy_discover, model=model)
