@@ -103,7 +103,7 @@ def rgb_to_int(x: Tuple[int, int, int]) -> int:
 
 
 def int_to_brightness(x: int) -> int:
-    """"Return brightness (0-100) from integer."""
+    """Return brightness (0-100) from integer."""
     return x >> 24
 
 
